==> Pyrogram-0.6.5-py3-none-any.whl: pyrogram/api/types/message_media_geo_live.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageMediaGeoLive(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0x7c3c2609``

    Args:
        geo: :class:`pyrogram.api.types.GeoPoint`
        period: :obj:`int`
    """
    ID = 0x7c3c2609

    def __init__(self, geo, period):
        self.geo = geo  # GeoPoint
        self.period = period  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageMediaGeoLive":
        # No flags
        
        geo = Object.read(b)
        
        period = Int.read(b)
        
        return MessageMediaGeoLive(geo, period)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.geo.write())
        
        b.write(Int(self.period))
        
        return b.getvalue()

==> Pyrogram-0.7.1-py3-none-any.whl: pyrogram/api/types/message_media_geo_live.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageMediaGeoLive(Object):
    """Attributes:
        ID: ``0x7c3c2609``

    Args:
        geo: Either :obj:`GeoPointEmpty <pyrogram.api.types.GeoPointEmpty>` or :obj:`GeoPoint <pyrogram.api.types.GeoPoint>`
        period: ``int`` ``32-bit``

    See Also:
        This object can be returned by :obj:`messages.GetWebPagePreview <pyrogram.api.functions.messages.GetWebPagePreview>` and :obj:`messages.UploadMedia <pyrogram.api.functions.messages.UploadMedia>`.
    """
    ID = 0x7c3c2609

    def __init__(self, geo, period):
        self.geo = geo  # GeoPoint
        self.period = period  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageMediaGeoLive":
        # No flags
        
        geo = Object.read(b)
        
        period = Int.read(b)
        
        return MessageMediaGeoLive(geo, period)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.geo.write())
        
        b.write(Int(self.period))
        
        return b.getvalue()
